==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ProviderRegistrationPropertiesProviderHubMetadataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesProviderHubMetadataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property providerAuthentication
 * @property providerAuthorizations
 * @property thirdPartyProviderAuthorization
 */
public data class ProviderRegistrationPropertiesProviderHubMetadataArgs(
    public val providerAuthentication: Output<ProviderHubMetadataProviderAuthenticationArgs>? = null,
    public val providerAuthorizations: Output<List<ResourceProviderAuthorizationArgs>>? = null,
    public val thirdPartyProviderAuthorization:
    Output<ProviderHubMetadataThirdPartyProviderAuthorizationArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesProviderHubMetadataArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesProviderHubMetadataArgs =
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesProviderHubMetadataArgs.builder()
            .providerAuthentication(
                providerAuthentication?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .providerAuthorizations(
                providerAuthorizations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .thirdPartyProviderAuthorization(
                thirdPartyProviderAuthorization?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            ).build()
}

/**
 * Builder for [ProviderRegistrationPropertiesProviderHubMetadataArgs].
 */
@PulumiTagMarker
public class ProviderRegistrationPropertiesProviderHubMetadataArgsBuilder internal constructor() {
    private var providerAuthentication: Output<ProviderHubMetadataProviderAuthenticationArgs>? = null

    private var providerAuthorizations: Output<List<ResourceProviderAuthorizationArgs>>? = null

    private var thirdPartyProviderAuthorization:
        Output<ProviderHubMetadataThirdPartyProviderAuthorizationArgs>? = null

    /**
     * @param value
     */
    @JvmName("hymdcmhhcfxjfynp")
    public suspend
    fun providerAuthentication(`value`: Output<ProviderHubMetadataProviderAuthenticationArgs>) {
        this.providerAuthentication = value
    }

    /**
     * @param value
     */
    @JvmName("ljehmkknpiaalreo")
    public suspend
    fun providerAuthorizations(`value`: Output<List<ResourceProviderAuthorizationArgs>>) {
        this.providerAuthorizations = value
    }

    @JvmName("cobmboxkiovwigew")
    public suspend fun providerAuthorizations(
        vararg
        values: Output<ResourceProviderAuthorizationArgs>,
    ) {
        this.providerAuthorizations = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("akgjppacovxqnong")
    public suspend
    fun providerAuthorizations(values: List<Output<ResourceProviderAuthorizationArgs>>) {
        this.providerAuthorizations = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("plhfpqsfwpglpvfg")
    public suspend
    fun thirdPartyProviderAuthorization(`value`: Output<ProviderHubMetadataThirdPartyProviderAuthorizationArgs>) {
        this.thirdPartyProviderAuthorization = value
    }

    /**
     * @param value
     */
    @JvmName("xaculbcnlrqomlnh")
    public suspend
    fun providerAuthentication(`value`: ProviderHubMetadataProviderAuthenticationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providerAuthentication = mapped
    }

    /**
     * @param argument
     */
    @JvmName("muftcyosfmtnyhpx")
    public suspend
    fun providerAuthentication(argument: suspend ProviderHubMetadataProviderAuthenticationArgsBuilder.() -> Unit) {
        val toBeMapped = ProviderHubMetadataProviderAuthenticationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.providerAuthentication = mapped
    }

    /**
     * @param value
     */
    @JvmName("chrnlhsschcfmgem")
    public suspend fun providerAuthorizations(`value`: List<ResourceProviderAuthorizationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providerAuthorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("dfxrfntcagjsbeil")
    public suspend
    fun providerAuthorizations(argument: List<suspend ResourceProviderAuthorizationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceProviderAuthorizationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.providerAuthorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ccdlgvfhsjuqwrge")
    public suspend fun providerAuthorizations(
        vararg
        argument: suspend ResourceProviderAuthorizationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceProviderAuthorizationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.providerAuthorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("yihvmuajmuquadco")
    public suspend
    fun providerAuthorizations(argument: suspend ResourceProviderAuthorizationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ResourceProviderAuthorizationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.providerAuthorizations = mapped
    }

    /**
     * @param values
     */
    @JvmName("ofqpffotcpvhynmu")
    public suspend fun providerAuthorizations(vararg values: ResourceProviderAuthorizationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.providerAuthorizations = mapped
    }

    /**
     * @param value
     */
    @JvmName("eicseexeudqrvkqm")
    public suspend
    fun thirdPartyProviderAuthorization(`value`: ProviderHubMetadataThirdPartyProviderAuthorizationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thirdPartyProviderAuthorization = mapped
    }

    /**
     * @param argument
     */
    @JvmName("uumhpodsnjnljfhy")
    public suspend
    fun thirdPartyProviderAuthorization(argument: suspend ProviderHubMetadataThirdPartyProviderAuthorizationArgsBuilder.() -> Unit) {
        val toBeMapped = ProviderHubMetadataThirdPartyProviderAuthorizationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.thirdPartyProviderAuthorization = mapped
    }

    internal fun build(): ProviderRegistrationPropertiesProviderHubMetadataArgs =
        ProviderRegistrationPropertiesProviderHubMetadataArgs(
            providerAuthentication = providerAuthentication,
            providerAuthorizations = providerAuthorizations,
            thirdPartyProviderAuthorization = thirdPartyProviderAuthorization,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ProviderRegistrationPropertiesProviderHubMetadataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesProviderHubMetadataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property providerAuthentication
 * @property providerAuthorizations
 * @property thirdPartyProviderAuthorization
 */
public data class ProviderRegistrationPropertiesProviderHubMetadataArgs(
    public val providerAuthentication: Output<ProviderHubMetadataProviderAuthenticationArgs>? = null,
    public val providerAuthorizations: Output<List<ResourceProviderAuthorizationArgs>>? = null,
    public val thirdPartyProviderAuthorization:
    Output<ProviderHubMetadataThirdPartyProviderAuthorizationArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesProviderHubMetadataArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesProviderHubMetadataArgs =
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesProviderHubMetadataArgs.builder()
            .providerAuthentication(
                providerAuthentication?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .providerAuthorizations(
                providerAuthorizations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .thirdPartyProviderAuthorization(
                thirdPartyProviderAuthorization?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            ).build()
}

/**
 * Builder for [ProviderRegistrationPropertiesProviderHubMetadataArgs].
 */
@PulumiTagMarker
public class ProviderRegistrationPropertiesProviderHubMetadataArgsBuilder internal constructor() {
    private var providerAuthentication: Output<ProviderHubMetadataProviderAuthenticationArgs>? = null

    private var providerAuthorizations: Output<List<ResourceProviderAuthorizationArgs>>? = null

    private var thirdPartyProviderAuthorization:
        Output<ProviderHubMetadataThirdPartyProviderAuthorizationArgs>? = null

    /**
     * @param value
     */
    @JvmName("gaoxtsgxfneudeqg")
    public suspend
    fun providerAuthentication(`value`: Output<ProviderHubMetadataProviderAuthenticationArgs>) {
        this.providerAuthentication = value
    }

    /**
     * @param value
     */
    @JvmName("hqohdungxkmlpghw")
    public suspend
    fun providerAuthorizations(`value`: Output<List<ResourceProviderAuthorizationArgs>>) {
        this.providerAuthorizations = value
    }

    @JvmName("ipsihpxybyxjkvjj")
    public suspend fun providerAuthorizations(
        vararg
        values: Output<ResourceProviderAuthorizationArgs>,
    ) {
        this.providerAuthorizations = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("adbhgxrpcmbeydua")
    public suspend
    fun providerAuthorizations(values: List<Output<ResourceProviderAuthorizationArgs>>) {
        this.providerAuthorizations = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("khhkmlfwiyqgpocw")
    public suspend
    fun thirdPartyProviderAuthorization(`value`: Output<ProviderHubMetadataThirdPartyProviderAuthorizationArgs>) {
        this.thirdPartyProviderAuthorization = value
    }

    /**
     * @param value
     */
    @JvmName("xxwcowohjgtdailj")
    public suspend
    fun providerAuthentication(`value`: ProviderHubMetadataProviderAuthenticationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providerAuthentication = mapped
    }

    /**
     * @param argument
     */
    @JvmName("wcslgxkyprgwytnf")
    public suspend
    fun providerAuthentication(argument: suspend ProviderHubMetadataProviderAuthenticationArgsBuilder.() -> Unit) {
        val toBeMapped = ProviderHubMetadataProviderAuthenticationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.providerAuthentication = mapped
    }

    /**
     * @param value
     */
    @JvmName("goaoyxlplyjiueic")
    public suspend fun providerAuthorizations(`value`: List<ResourceProviderAuthorizationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providerAuthorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("gysuwrurgjnqssnx")
    public suspend
    fun providerAuthorizations(argument: List<suspend ResourceProviderAuthorizationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceProviderAuthorizationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.providerAuthorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ioxcvqnagrsxwbgr")
    public suspend fun providerAuthorizations(
        vararg
        argument: suspend ResourceProviderAuthorizationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceProviderAuthorizationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.providerAuthorizations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("xjbyqftgglhqoith")
    public suspend
    fun providerAuthorizations(argument: suspend ResourceProviderAuthorizationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ResourceProviderAuthorizationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.providerAuthorizations = mapped
    }

    /**
     * @param values
     */
    @JvmName("tmbfejhqvuwdjujp")
    public suspend fun providerAuthorizations(vararg values: ResourceProviderAuthorizationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.providerAuthorizations = mapped
    }

    /**
     * @param value
     */
    @JvmName("pcneusjoqiuvuunw")
    public suspend
    fun thirdPartyProviderAuthorization(`value`: ProviderHubMetadataThirdPartyProviderAuthorizationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thirdPartyProviderAuthorization = mapped
    }

    /**
     * @param argument
     */
    @JvmName("kwwhxmfduyakiaxb")
    public suspend
    fun thirdPartyProviderAuthorization(argument: suspend ProviderHubMetadataThirdPartyProviderAuthorizationArgsBuilder.() -> Unit) {
        val toBeMapped = ProviderHubMetadataThirdPartyProviderAuthorizationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.thirdPartyProviderAuthorization = mapped
    }

    internal fun build(): ProviderRegistrationPropertiesProviderHubMetadataArgs =
        ProviderRegistrationPropertiesProviderHubMetadataArgs(
            providerAuthentication = providerAuthentication,
            providerAuthorizations = providerAuthorizations,
            thirdPartyProviderAuthorization = thirdPartyProviderAuthorization,
        )
}
